﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace SHP2TXT
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void btnSHP_Click(object sender, EventArgs e)
        {
            openFileDialog.FileName = "";
            openFileDialog.Filter = "SHP Files(*.shp)|*.shp|All Files(*.*)|*.*";
            openFileDialog.FilterIndex = 0;
            DialogResult DR = openFileDialog.ShowDialog();
            if (DR == DialogResult.OK)
            {
                tbSHP.Text = openFileDialog.FileName;
            }
        }

        private void btnTXT_Click(object sender, EventArgs e)
        {
            saveFileDialog.FileName = "";
            saveFileDialog.Filter = "SHP Files(*.shp)|*.shp|All Files(*.*)|*.*";
            saveFileDialog.FilterIndex = 0;
            DialogResult DR = saveFileDialog.ShowDialog();
            if (DR == DialogResult.OK)
            {
                tbSHP.Text = openFileDialog.FileName;
            }
        }

        private void btnConvert_Click(object sender, EventArgs e)
        {
            axXr1.Layers.RemoveAllLayer();
            axXr1.Layers.AddShapeMapLayer("map", openFileDialog.FileName);
            axXr1.WaitForAllConnections();

            if (axXr1.Layers.IsLayerExist("map"))
            {
                XrMapLib.IShapeMapLayer lyr = axXr1.Layers.GetLayerAsShapeMap("map");
                XrMapLib.IShapeTable shpTbl = lyr.ShapeTable;
                XrMapLib.IAttributeTable attTbl = lyr.AttributeTable;

                FileStream fo = null;
                StreamWriter so = null;
                try
                {
                    fo = new FileStream(tbTXT.Text, FileMode.Create);
                    so = new StreamWriter(fo, System.Text.Encoding.Default);
                }
                catch (Exception)
                {
                    MessageBox.Show("저장할 Text 파일을 옳바르게 지정해주세요.");
                    return;
                }

                int FID = 0;
                XrMapLib.IShapeRow sRow = null;
                XrMapLib.IAttributeRow aRow = null;
                int cntFields = attTbl.FieldSet.FieldCount;
                while ((sRow = shpTbl.GetRow(FID)) != null)
                {
                    XrMapLib.IExtent MBR = sRow.Extent;
                    if (sRow.Load())
                    {
                        if (shpTbl.ShapeType == XrMapLib.XrShapeTypeEnum.XrPoint)
                        {
                            so.Write("<shape begin>");
                            XrMapLib.Coordinate coord = sRow.GetVertex(0);
                            so.Write("(" + coord.X + "," + coord.Y + ")");
                            so.Write("<shape end>");
                        }
                        else
                        {
                            int cntParts = sRow.PartCount;
                            for (int iPart = 0; iPart < cntParts; ++iPart)
                            {
                                so.Write("<shape begin>");
                                int cntVtx = sRow.GetVertexCountFromPart(iPart);
                                for (int iVtx = 0; iVtx < cntVtx; ++iVtx)
                                {
                                    XrMapLib.Coordinate coord = sRow.GetVertexFromPart(iPart, iVtx);
                                    so.Write("(" + coord.X + "," + coord.Y + ")");
                                }
                                so.Write("<shape end>");
                            }
                        }

                        sRow.Unload();
                    }

                    aRow = attTbl.GetRow(FID);
                    if (aRow.Load())
                    {
                        so.Write("<attribute begin>");
                        for(int iField=0; iField<cntFields; ++iField)
                        {
                            String value = aRow.GetValueAsString(iField);
                            so.Write(value);
                            if (iField != cntFields - 1)
                            {
                                so.Write("|");
                            }

                        }
                        so.Write("<attribute end>");
                        

                        aRow.Unload();
                    }

                    FID++;
                }

                so.Close();
            }
            else
            {
                MessageBox.Show("SHP 파일을 옳바르지 지정해주세요.");
            }

            MessageBox.Show("완료");
        }
    }
}
